@@ -129,11 +129,12 @@ STRUCTURE = Nav(
 			],
 		),
 		Nav(
-			lazy_gettext("Maths"),
+			lazy_gettext("Tools"),
 			index=True,
 			children=[
 				Nav(lazy_gettext("Combo A + B")),
 				Nav(lazy_gettext("Ik-O-Maths")),
+				Nav(lazy_gettext("Tirage au sort")),
 			],
 		),
 	],
